@@ -1,12 +1,10 @@
 
 import unittest
 import sys
+from urllib.request import urlopen
 
 import shorttext
-if sys.version_info[0]==2:
-    from urllib2 import urlopen
-else:
-    from urllib.request import urlopen
+
 
 class TestCharOneHot(unittest.TestCase):
     def setUp(self):
@@ -16,9 +14,8 @@ class TestCharOneHot(unittest.TestCase):
         pass
 
     def test_BigTxt(self):
-        encoding = 'utf-8' if sys.version_info[0]==3 else None
         chartovec_encoder = shorttext.generators.initSentenceToCharVecEncoder(urlopen('http://norvig.com/big.txt'),
-                                                                              encoding=encoding)
+                                                                              encoding='utf-8')
         self.assertEqual(93, len(chartovec_encoder.dictionary))
         self.assertEqual('\n', chartovec_encoder.signalchar)
 
